@@ -12,9 +12,7 @@ import threading
 import datetime
 import binascii
 import uuid
-from lib import exc
-from lib import objects
-print("Discord\thttps://discord.gg/BnAFAPsc\naminolib.py 0.0.5")
+print("Discord\thttps://discord.gg/BnAFAPsc\naminolib.py 0.0.7")
 class Client:
 	def __init__(self, device: str=None):
 		if device is not None:self.device = device
