@@ -32,7 +32,7 @@ class wallet:
 		self.coins = None
 		try:self.coins = self.data["totalCoins"]
 		except KeyError:pass
-		try:self.floatcoins = self.dafa["totalCoinsFloat"]
+		try:self.floatcoins = self.data["totalCoinsFloat"]
 		except KeyError:pass
 class userProfileList:
 	def __init__(self,data):
